import json
import tempfile
import gradio as gr

from os.path import join, dirname
from ovos_utils import LOG

TTS = None


def tts(text: str, language: str):
    print(text, language)
    # return output
    with tempfile.NamedTemporaryFile(suffix=".wav", delete=False) as fp:
        TTS.get_tts(text, fp, speaker={"language": language})
        return fp.name


def bind_gradio_service(app, tts_engine, title, description, info, badge,
                        default_lang="en"):
    global TTS
    TTS = tts_engine

    languages = list(tts_engine.available_languages or [default_lang])
    languages.sort()
    LOG.debug(languages)

    if default_lang not in languages:
        LOG.warning(f"{default_lang} not in languages, trying ISO 639-1 code")
        default_lang = default_lang.split('-')[0]
    if default_lang not in languages:
        LOG.warning(f"{default_lang} not in languages, choosing first lang")
        default_lang = languages[0]

    try:
        example_file = "rainbow.json"
        with open(join(dirname(__file__), "examples", example_file), 'r') as f:
            examples = json.load(f)
    except Exception as e:
        LOG.error(e)
        examples = dict()

    with gr.Blocks() as blocks:
        gr.Markdown("<h1 style='text-align: center; margin-bottom: 1rem'>"
                    + title
                    + "</h1>")
        gr.Markdown(description)
        with gr.Row():  # equal_height=False
            with gr.Column():  # variant="panel"
                textbox = gr.Textbox(
                    label="Input",
                    value=examples.get(default_lang),
                    max_lines=3,
                )
                radio = gr.Radio(
                    label="Language",
                    choices=languages,
                    value=default_lang
                )
                with gr.Row():  # mobile_collapse=False
                    submit = gr.Button("Submit", variant="primary")
            audio = gr.Audio(label="Output", interactive=False)
        gr.Markdown(info)
        gr.Markdown("<center>"
                    + f'<img src={badge} alt="visitors badge"/>'
                    + "</center>")

        # actions
        submit.click(
            tts,
            [textbox, radio],
            [audio],
        )
        radio.change(lambda lang: examples.get(lang), radio, textbox)
    LOG.info(f"Mounting app to /gradio")
    gr.mount_gradio_app(app, blocks, path="/gradio")



#!/usr/bin/env python3
from setuptools import setup, find_packages
from os import path, environ

BASE_PATH = path.abspath(path.dirname(__file__))


def required(requirements_file):
    """ Read requirements file and remove comments and empty lines. """
    with open(path.join(BASE_PATH, requirements_file), 'r') as f:
        requirements = f.read().splitlines()
        if 'MYCROFT_LOOSE_REQUIREMENTS' in environ:
            print('USING LOOSE REQUIREMENTS!')
            requirements = [r.replace('==', '>=').replace('~=', '>=') for r in requirements]
        return [pkg for pkg in requirements
                if pkg.strip() and not pkg.startswith("#")]


with open(path.join(BASE_PATH, "readme.md"), "r") as f:
    long_description = f.read()

def get_version():
    """ Find the version of ovos-core"""
    version = None
    version_file = path.join(BASE_PATH, 'ovos_tts_server', 'version.py')
    major, minor, build, alpha = (None, None, None, None)
    with open(version_file) as f:
        for line in f:
            if 'VERSION_MAJOR' in line:
                major = line.split('=')[1].strip()
            elif 'VERSION_MINOR' in line:
                minor = line.split('=')[1].strip()
            elif 'VERSION_BUILD' in line:
                build = line.split('=')[1].strip()
            elif 'VERSION_ALPHA' in line:
                alpha = line.split('=')[1].strip()

            if ((major and minor and build and alpha) or
                    '# END_VERSION_BLOCK' in line):
                break
    version = f"{major}.{minor}.{build}"
    if int(alpha):
        version += f"a{alpha}"
    return version

setup(
    name='ovos-tts-server',
    version=get_version(),
    description='simple FastAPI server to host TTS plugins as a service',
    long_description=long_description,
    long_description_content_type="text/markdown",
    url='https://github.com/OpenVoiceOS/ovos-tts-server',
    author='JarbasAi',
    author_email='jarbasai@mailfence.com',
    license='Apache-2.0',
    packages=find_packages(),
    install_requires=required("requirements/requirements.txt"),
    package_data={"ovos_tts_server": ["examples/*"]},
    zip_safe=True,
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Text Processing :: Linguistic',
        'License :: OSI Approved :: Apache Software License',

        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.0',
        'Programming Language :: Python :: 3.1',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
    keywords='plugin TTS OVOS OpenVoiceOS',
    entry_points={
        'console_scripts': [
            'ovos-tts-server=ovos_tts_server.__main__:main'
        ]
    }
)
